==> automata-core-0.5.2-sources.jar: net/automatalib/words/impl/Alphabets.java <==
/* Copyright (C) 2013 TU Dortmund
 * This file is part of AutomataLib, http://www.automatalib.net/.
 * 
 * AutomataLib is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 3.0 as published by the Free Software Foundation.
 * 
 * AutomataLib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with AutomataLib; if not, see
 * http://www.gnu.de/documents/lgpl.en.html.
 */
package net.automatalib.words.impl;

import java.util.Collections;
import java.util.List;

import net.automatalib.commons.util.collections.CollectionsUtil;
import net.automatalib.words.Alphabet;

public abstract class Alphabets {

	public static <T> Alphabet<T> fromList(List<? extends T> list) {
		return new ListAlphabet<>(list);
	}
	
	@SafeVarargs
	public static <T> Alphabet<T> fromArray(T ...symbols) {
		return new ArrayAlphabet<>(symbols);
	}
	
	public static <E extends Enum<E>> Alphabet<E> fromEnum(Class<E> enumClazz, boolean withNull) {
		return new EnumAlphabet<>(enumClazz, withNull);
	}
	
	public static <E extends Enum<E>> Alphabet<E> fromEnum(Class<E> enumClazz) {
		return fromEnum(enumClazz, false);
	}
	
	public static Alphabet<Integer> integers(int startInclusive, int endInclusive) {
		List<Integer> lst = CollectionsUtil.intRange(startInclusive, endInclusive + 1);
		return fromList(lst);
	}
	
	public static Alphabet<Character> characters(char startInclusive, char endInclusive) {
		List<Character> lst = CollectionsUtil.charRange(startInclusive, (char)(endInclusive + 1));
		return fromList(lst);
	}
	
	public static Alphabet<String> closedCharStringRange(char startInclusive, char endInclusive) {
		List<String> lst = CollectionsUtil.charStringRange(startInclusive, (char)(endInclusive + 1));
		return fromList(lst);
	}
	
	public static <T> Alphabet<T> singleton(T symbol) {
		return fromList(Collections.singletonList(symbol));
	}
	
	
	private Alphabets() {
		// prevent inheritance
	}

}

==> automata-core-0.6.0-sources.jar: net/automatalib/words/impl/Alphabets.java <==
/* Copyright (C) 2013 TU Dortmund
 * This file is part of AutomataLib, http://www.automatalib.net/.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.automatalib.words.impl;

import java.util.Collection;
import java.util.Collections;
import java.util.List;

import net.automatalib.commons.util.collections.CollectionsUtil;
import net.automatalib.words.Alphabet;

public abstract class Alphabets {

	public static <T> Alphabet<T> fromList(List<? extends T> list) {
		return new ListAlphabet<>(list);
	}
	
	@SafeVarargs
	public static <T> Alphabet<T> fromArray(T ...symbols) {
		return new ArrayAlphabet<>(symbols);
	}
	
	public static <E extends Enum<E>> Alphabet<E> fromEnum(Class<E> enumClazz, boolean withNull) {
		return new EnumAlphabet<>(enumClazz, withNull);
	}
	
	public static <E extends Enum<E>> Alphabet<E> fromEnum(Class<E> enumClazz) {
		return fromEnum(enumClazz, false);
	}
	
	public static Alphabet<Integer> integers(int startInclusive, int endInclusive) {
		List<Integer> lst = CollectionsUtil.intRange(startInclusive, endInclusive + 1);
		return fromList(lst);
	}
	
	public static Alphabet<Character> characters(char startInclusive, char endInclusive) {
		List<Character> lst = CollectionsUtil.charRange(startInclusive, (char)(endInclusive + 1));
		return fromList(lst);
	}
	
	public static Alphabet<String> closedCharStringRange(char startInclusive, char endInclusive) {
		List<String> lst = CollectionsUtil.charStringRange(startInclusive, (char)(endInclusive + 1));
		return fromList(lst);
	}
	
	public static <T> Alphabet<T> singleton(T symbol) {
		return fromList(Collections.singletonList(symbol));
	}
	
	@SuppressWarnings("unchecked")
	public static <I> Alphabet<I> fromCollection(Collection<? extends I> coll) {
		if (coll instanceof Alphabet) {
			return (Alphabet<I>) coll;
		}
		return new SimpleAlphabet<>(coll);
	}
	
	private Alphabets() {
		// prevent inheritance
	}

}
